==> libksysguard-5.17.3-1-arm.pkg.tar.xz: usr/lib/cmake/KF5SysGuard/KF5SysGuardLibraryTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::LsofUi" for configuration ""
set_property(TARGET KF5::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/liblsofui.so.5.17.3"
  IMPORTED_SONAME_NOCONFIG "liblsofui.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::LsofUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::LsofUi "${_IMPORT_PREFIX}/lib/liblsofui.so.5.17.3" )

# Import target "KF5::ProcessCore" for configuration ""
set_property(TARGET KF5::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::AuthCore;KF5::CoreAddons"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.17.3"
  IMPORTED_SONAME_NOCONFIG "libprocesscore.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::ProcessCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.17.3" )

# Import target "KF5::ProcessUi" for configuration ""
set_property(TARGET KF5::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::DBus;KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::Completion;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::GlobalAccel;KF5::Service;KF5::KIOWidgets;Qt5::X11Extras"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocessui.so.5.17.3"
  IMPORTED_SONAME_NOCONFIG "libprocessui.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::ProcessUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::ProcessUi "${_IMPORT_PREFIX}/lib/libprocessui.so.5.17.3" )

# Import target "KF5::SignalPlotter" for configuration ""
set_property(TARGET KF5::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::ProcessCore;KF5::Plasma"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.17.3"
  IMPORTED_SONAME_NOCONFIG "libksignalplotter.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::SignalPlotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::SignalPlotter "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.17.3" )

# Import target "KF5::SysGuard" for configuration ""
set_property(TARGET KF5::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::CoreAddons;KF5::ConfigWidgets;KF5::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksgrd.so.5.17.3"
  IMPORTED_SONAME_NOCONFIG "libksgrd.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::SysGuard )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::SysGuard "${_IMPORT_PREFIX}/lib/libksgrd.so.5.17.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksysguard-5.17.4-1-arm.pkg.tar.xz: usr/lib/cmake/KF5SysGuard/KF5SysGuardLibraryTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::LsofUi" for configuration ""
set_property(TARGET KF5::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/liblsofui.so.5.17.4"
  IMPORTED_SONAME_NOCONFIG "liblsofui.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::LsofUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::LsofUi "${_IMPORT_PREFIX}/lib/liblsofui.so.5.17.4" )

# Import target "KF5::ProcessCore" for configuration ""
set_property(TARGET KF5::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::AuthCore;KF5::CoreAddons"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.17.4"
  IMPORTED_SONAME_NOCONFIG "libprocesscore.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::ProcessCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.17.4" )

# Import target "KF5::ProcessUi" for configuration ""
set_property(TARGET KF5::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::DBus;Qt5::WebChannel;KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::Completion;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::GlobalAccel;KF5::Service;KF5::KIOWidgets;Qt5::X11Extras"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocessui.so.5.17.4"
  IMPORTED_SONAME_NOCONFIG "libprocessui.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::ProcessUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::ProcessUi "${_IMPORT_PREFIX}/lib/libprocessui.so.5.17.4" )

# Import target "KF5::SignalPlotter" for configuration ""
set_property(TARGET KF5::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::ProcessCore;KF5::Plasma"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.17.4"
  IMPORTED_SONAME_NOCONFIG "libksignalplotter.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::SignalPlotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::SignalPlotter "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.17.4" )

# Import target "KF5::SysGuard" for configuration ""
set_property(TARGET KF5::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::CoreAddons;KF5::ConfigWidgets;KF5::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksgrd.so.5.17.4"
  IMPORTED_SONAME_NOCONFIG "libksgrd.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::SysGuard )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::SysGuard "${_IMPORT_PREFIX}/lib/libksgrd.so.5.17.4" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
